## GeneBe Utils
Welcome to GeneBe Utils, a Python package that complements the innovative GeneBe platform. GeneBe is a cutting-edge genetics platform designed to empower individuals with insights into their health and well-being.

Using this client, you can easily annotate your DNA variants with the GeneBe API. Annotations include:
* Gene, transcript, and effect
* ClinVar phenotype
* GnomAD frequency
* ACMG score
* ... if you need more, please let me know

### Usage

#### Command line usage

Check current options using `--help` switch

```
genebe --help
```

Or just call

```
genebe input.vcf.gz output.vcf.gz
```

For annotating your VCF file with `acmg_score` field.

To use VCF annoation you have to have `cyvcf2` package installed. Take a look at the Installation section below.

#### Python usage

GeneBe makes annotating DNA variants in pandas dataframe easy.

```python
import genebe as gnb

input_variants = ['7-69599651-A-G']

# output as a list, with all transcripts
list = gnb.annotate_variants_list(input_variants,flatten_consequences = False)

# output as a pandas dataframe, flat
df = gnb.annotate_variants_list_to_dataframe(input_variants, flatten_consequences=True)

# parse HGVS
input_hgvs = ['NM_000277.2:c.1A>G']
parsed_variants = gnb.parse_hgvs(input_hgvs)

```

If you want to annotate thousands of variants, please log in to https://genebe.net, generate an API Key, and provide it using `username` and `api_key`.

### Installation
You can install GeneBe Utils using pip:

```
pip install genebe
```

If you wish to install faster `mmh3` implementation or use the option of annotating vcf files install using:

```
pip install genebe[cpp]
```

or install modules

```
pip install cyvcf2
pip install mmh3
```

in the environment.

This step will require build tools installed on your computer.




For more information about GeneBe, visit GeneBe website, https://genebe.net .




